pub struct NoopCommunicationBackend;Expand description
A no-op implementation of the CommunicationBackend trait.
Sending discards messages silently and receiving blocks forever (the future never resolves). This is useful as a default backend for platforms that do not need IPC communication.